==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderBuilder extends OrderFluentImpl<OrderBuilder> implements VisitableBuilder<Order,OrderBuilder>{
  public OrderBuilder() {
    this(false);
  }
  public OrderBuilder(Boolean validationEnabled) {
    this(new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance) {
    this(fluent, instance, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OrderBuilder(Order instance) {
    this(instance,false);
  }
  public OrderBuilder(Order instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  OrderFluent<?> fluent;
  Boolean validationEnabled;
  public Order build() {
    Order buildable = new Order(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderBuilder extends OrderFluent<OrderBuilder> implements VisitableBuilder<Order,OrderBuilder>{
  public OrderBuilder() {
    this(false);
  }
  public OrderBuilder(Boolean validationEnabled) {
    this(new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Order(), validationEnabled);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance) {
    this(fluent, instance, false);
  }
  public OrderBuilder(OrderFluent<?> fluent,Order instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Order());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OrderBuilder(Order instance) {
    this(instance,false);
  }
  public OrderBuilder(Order instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Order());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  OrderFluent<?> fluent;
  Boolean validationEnabled;
  public Order build() {
    Order buildable = new Order(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    return buildable;
  }
  
}
